@@ -38,12 +38,13 @@ AffySimStudy <- function(n, M, eps, seed = 123, eps.lower = 0, eps.upper = 0.05,
 
 
     if(plot2){
-        ind <- sample(1:M, min(M, 20))
+        ind <- if(M <= 20) 1:M else sample(1:M, 20)
         if(plot1) dev.new()
+        M1 <- min(M, 20)
         print(
-          stripplot(rep(1:min(M, 20), each = n) ~ as.vector(Mre[ind,]), 
+          stripplot(rep(1:M1, each = n) ~ as.vector(Mre[ind,]), 
                     ylab = "samples", xlab = "x", pch = 20,
-                    main = "Randomly chosen samples")
+                    main = ifelse(M <= 20, "Samples", "20 randomly chosen samples"))
         )
     }
 
